@@ -18,21 +18,20 @@ class NotificationManager:
         self._logger = logger
         self._to_publish = []
 
-    def stage(self, event_type: str, message, group_id: str, **kwargs):
-        self._to_publish.append((event_type, message, group_id, kwargs))
+    def stage(self, event_type: str, message, **kwargs):
+        self._to_publish.append((event_type, message, kwargs))
 
     def flush(self):
         with concurrent.futures.ThreadPoolExecutor(max_workers=16) as executor:
             for to_publish in self._to_publish:
                 executor.submit(self.publish, *to_publish[:-1], **to_publish[-1])
 
-    def publish(self, event_type: str, message, group_id: str, **kwargs):
+    def publish(self, event_type: str, message, **kwargs):
         if type(message) is not str:
             message = message.json()
         try:
             self._publish(
                 message=message,
-                group_id=group_id,
                 message_attributes={
                     "eventType": {
                         "DataType": "String",
@@ -49,11 +48,10 @@ class NotificationManager:
                 self._logger.exception(f"Didn't publish the notification because previous attempts failed")
 
     @circuitbreaker.circuit(failure_threshold=1, recovery_timeout=None, expected_exception=InternalError)
-    def _publish(self, message_attributes: Dict, message: str, group_id: str):
+    def _publish(self, message_attributes: Dict, message: str):
         try:
             response = self._sns_topic.publish(
                 Message=message,
-                MessageGroupId=group_id,
                 MessageAttributes=message_attributes,
             )
         except botocore.exceptions.ClientError as e:
